# NamedLinop

::: torchlinops.linops.NamedLinop
    options:
        inherited_members: false
        members:
            - __init__
            - forward
            - fn
            - adj_fn
            - normal_fn
            - split_forward
            - size
            - dims
            - H
            - adjoint
            - N
            - normal
            - split
            - adj_split
            - flatten
            - compose
            - apply
            - to
            - reset_adjoint_and_normal
